==> react-molecule-tabs-2.19.0.tgz: package/lib/hoc/withStateActiveTab.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { Children, cloneElement, Component } from 'react';
import PropTypes from 'prop-types';

var withStateActiveTab = function withStateActiveTab(BaseComponent) {
  var _class, _temp;

  var displayName = BaseComponent.displayName;
  return _temp = _class = /*#__PURE__*/function (_Component) {
    _inheritsLoose(BaseComponentWithState, _Component);

    function BaseComponentWithState() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _Component.call.apply(_Component, [this].concat(args)) || this;
      _this.state = {
        activeTab: null
      };

      _this.onChange = function (e, _ref) {
        var numTab = _ref.numTab;
        var onChange = _this.props.onChange;

        _this.setState({
          activeTab: numTab
        }, function () {
          return onChange(e, {
            numTab: numTab
          });
        });
      };

      return _this;
    }

    var _proto = BaseComponentWithState.prototype;

    _proto.componentDidMount = function componentDidMount() {
      var _this2 = this;

      var children = this.props.children; // eslint-disable-line

      Children.forEach(children, function (child, index) {
        var active = child.props.active;
        if (active) _this2.setState({
          activeTab: index + 1
        });
      });
    };

    _proto.render = function render() {
      var value = this.state.value;
      var extendedChildren = this.extendedChildren,
          onChange = this.onChange,
          props = this.props;
      return /*#__PURE__*/_jsx(BaseComponent, _extends({}, props, {
        value: value,
        onChange: onChange,
        children: extendedChildren
      }));
    };

    _createClass(BaseComponentWithState, [{
      key: "extendedChildren",
      get: function get() {
        var children = this.props.children; // eslint-disable-line

        var activeTab = this.state.activeTab;
        return Children.toArray(children).filter(Boolean).map(function (child, index, children) {
          var numTab = index + 1;
          var active = activeTab === numTab;
          return /*#__PURE__*/cloneElement(child, {
            active: active
          });
        });
      }
    }]);

    return BaseComponentWithState;
  }(Component), _class.displayName = "withStateActiveTab(" + displayName + ")", _class.propTypes = {
    /** value */
    activeTab: PropTypes.any,

    /** onChange callback  */
    onChange: PropTypes.func
  }, _class.defaultProps = {
    onChange: function onChange() {}
  }, _temp;
};

export default withStateActiveTab;

==> react-molecule-tabs-2.20.0.tgz: package/lib/hoc/withStateActiveTab.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { Children, cloneElement, Component } from 'react';
import PropTypes from 'prop-types';
import { jsx as _jsx } from "react/jsx-runtime";

var withStateActiveTab = function withStateActiveTab(BaseComponent) {
  var _class, _temp;

  var displayName = BaseComponent.displayName;
  return _temp = _class = /*#__PURE__*/function (_Component) {
    _inheritsLoose(BaseComponentWithState, _Component);

    function BaseComponentWithState() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _Component.call.apply(_Component, [this].concat(args)) || this;
      _this.state = {
        activeTab: null
      };

      _this.onChange = function (e, _ref) {
        var numTab = _ref.numTab;
        var onChange = _this.props.onChange;

        _this.setState({
          activeTab: numTab
        }, function () {
          return onChange(e, {
            numTab: numTab
          });
        });
      };

      return _this;
    }

    var _proto = BaseComponentWithState.prototype;

    _proto.componentDidMount = function componentDidMount() {
      var _this2 = this;

      var children = this.props.children; // eslint-disable-line

      Children.forEach(children, function (child, index) {
        var active = child.props.active;
        if (active) _this2.setState({
          activeTab: index + 1
        });
      });
    };

    _proto.render = function render() {
      var value = this.state.value;
      var extendedChildren = this.extendedChildren,
          onChange = this.onChange,
          props = this.props;
      return /*#__PURE__*/_jsx(BaseComponent, _extends({}, props, {
        value: value,
        onChange: onChange,
        children: extendedChildren
      }));
    };

    _createClass(BaseComponentWithState, [{
      key: "extendedChildren",
      get: function get() {
        var children = this.props.children; // eslint-disable-line

        var activeTab = this.state.activeTab;
        return Children.toArray(children).filter(Boolean).map(function (child, index, children) {
          var numTab = index + 1;
          var active = activeTab === numTab;
          return /*#__PURE__*/cloneElement(child, {
            active: active
          });
        });
      }
    }]);

    return BaseComponentWithState;
  }(Component), _class.displayName = "withStateActiveTab(" + displayName + ")", _class.defaultProps = {
    onChange: function onChange() {}
  }, _temp;
};

export default withStateActiveTab;
